from freemocap import fmc_runme,recordingconfig

import zipfile
from pathlib import Path
import tkinter as tk
from tkinter import Tk, Label, Button, Frame, Listbox, Entry, filedialog

def DemoSetup():

    
    download_data = runDataDownloadGUI() #ask for user input on downloading
    
    if  download_data: #if they want to download
        #code to download stuff from online will go here


        #run the GUI to get the directory locations of the zipped folder, and where to extract it to
        locationPath, destinationPath = runDemoGUI() 
        zipPath = Path(locationPath)/'sesh_21-07-18_170130.zip' #append the name of the zipped sample file to the path to find it
        extractToPath = Path(destinationPath)/recordingconfig.dataFolder #append the name of the data folder to the destination path
        extractToPath.mkdir(exist_ok=True) #make the data folder if it doesn't current exist
        
        with zipfile.ZipFile(zipPath,'r') as zip_ref:
            zip_ref.extractall(extractToPath) #extract stuff to the data folder
    else:
        root = tk.Tk() #brinng up a window to select the data folder directory
        root.withdraw()
        destinationPath = filedialog.askdirectory( title='Select the directory where the Freemocap_data folder with the sample data is located',
            initialdir= Path.cwd())


    return destinationPath #take the path to the directory where the data folder is located

class DemoGUI(): #GUI to pick the location and the destination directories for the sample data 
        def __init__(self, master):
            self.master = master
            
            dataText = "Select the directory where your sample data is located"
            dataLable = Label(master, text=dataText)
            dataLable.pack(side="top")

            self.locationPathVar = tk.StringVar()
            savedLocationLabel = Label(master,textvariable=self.locationPathVar)
            savedLocationLabel.pack()

            dataButton = Button(master,text = 'Select the current sample data location',command = self.openLocationDialog)
            dataButton.pack()

            sampleDestinationText = "If a {} folder already exists, choose the directory where it is located. \n Otherwise, choose a directory to create a {} folder".format(recordingconfig.dataFolder,recordingconfig.dataFolder)
            sampleDestinationLabel = Label(master, text=sampleDestinationText)
            sampleDestinationLabel.pack()

            self.destinationPathVar = tk.StringVar()
            savedDestinationLabel = Label(master,textvariable=self.destinationPathVar)
            savedDestinationLabel.pack()

            sampleDestinationButton = Button(master,text = 'Select the sample data destination',command = self.openDestinationDialog)
            sampleDestinationButton.pack()

            submitButton = Button(master,text = 'Submit',command = self.submit)
            submitButton.pack()

        def openLocationDialog(self):
     
            self.locationPath = filedialog.askdirectory(
            title='Select the directory where the sample data zip file is located',
            initialdir= Path.cwd())

            self.locationPathVar.set(self.locationPath)
            f = 2
        
        def openDestinationDialog(self):
     
            self.destinationPath = filedialog.askdirectory(
            title='Select the directory where the freemocap data is located or should be created',
            initialdir= Path.cwd())
            f = 2

            self.destinationPathVar.set(self.destinationPath)
        
        def submit(self):
            self.master.destroy()


        def getLocationPath(self):
            return self.locationPath
        
        def getDestinationPath(self):
            return self.destinationPath

class dataDownloadGUI(): #GUI to ask whether users want to download data
    def __init__(self, master):
        self.master = master
    
        dataText = "Would you like to download sample data?"
        dataLable = Label(master, text=dataText)
        dataLable.pack(side="top")

        yesButton =  Button(master,text = 'Yes',command = self.yes)
        yesButton.pack()

        noButton =  Button(master,text = 'No',command = self.no)
        noButton.pack()

    def yes(self):
        self.download_sample_data = True
        self.master.destroy()
        

    def no(self):
        self.download_sample_data = False
        self.master.destroy()


def runDemoGUI():
    root = tk.Tk()
    pathchoices = DemoGUI(root)
    root.mainloop()

    locationPath = pathchoices.locationPath
    destinationPath = pathchoices.destinationPath

    return locationPath,destinationPath

def runDataDownloadGUI():
    root = tk.Tk()
    download_options = dataDownloadGUI(root)
    root.mainloop()

    return download_options.download_sample_data





from freemocap import (
    recordingconfig,
    runcams,
    runmeGUI,
    calibrate,
    fmc_mediapipe,
    fmc_openpose,
    fmc_deeplabcut,
    reconstruct3D,
    play_skeleton_animation,
    session,
    webcamGUI
)


from pathlib import Path
import os

from aniposelib.boards import CharucoBoard

import numpy as np

from ruamel.yaml import YAML

def RunMe(sessionID=None,
        stage=1,
        useOpenPose=False, 
        runOpenPose = True, 
        useMediaPipe=True,
        useDLC=False,
        runMediaPipe=False,
        dlcConfigPath=None,
        debug=False,
        setDataPath = False,
        userDataPath = None,
        recordVid = True,
        reconstructionConfidenceThreshold = .7,
        charucoSquareSize = 36,#mm - ~the size of the squares when printed on 8.5x11" paper based on parameters in ReadMe.md
        calVideoFrameLength = 120,
        ):
    """ 
    Starts the freemocap pipeline based on either user-input values, or default values. Creates a new session class instance (called sesh)
    based on the specified inputs. Checks for previous user preferences and choices if they exist, or will prompt the user for new choices
    if they don't. Runs the initialization for the system and runs each stage of the pipeline.
    """ 
    sesh = session.Session()

    sesh.sessionID = sessionID
    sesh.useOpenPose= useOpenPose
    sesh.useMediaPipe = useMediaPipe
    sesh.useDLC= useDLC
    sesh.debug = debug
    sesh.setDataPath = setDataPath
    sesh.userDataPath = userDataPath
    sesh.dataFolderName = recordingconfig.dataFolder

    if sesh.useDLC and stage < 5: 
        import deeplabcut as dlc
    #    sesh.dlcConfigPath = dlcConfigPath



    #%% load user preferences if they exist, create a new preferences yaml if they don't
    here = Path(__file__).parent
    preferences_path = here/'user_preferences.yaml'
    preferences_yaml = YAML()

    if preferences_path.exists():
        preferences = preferences_yaml.load(preferences_path)
    else:
        preferences = recordingconfig.parameters_for_yaml
        preferences_yaml.dump(preferences, preferences_path)
    
    sesh.preferences = preferences
    sesh.preferences_path = preferences_path
        

    if sesh.useDLC and stage < 5:

        try:
            saved_dlc_paths = preferences['saved']['dlc_config_paths']
        except: 
            saved_dlc_paths = preferences['default']['dlc_config_paths']


        dlc_config_paths = runmeGUI.RunChooseDLCPathGUI(sesh,saved_dlc_paths)
        

        sesh.preferences['saved']['dlc_config_paths'] = dlc_config_paths
        sesh.save_user_preferences(sesh.preferences)

        # sesh.dlcConfigPath = Path("C:\\Users\\jonma\\Dropbox\\GitKrakenRepos\\freemocap\\DLC_Models\\PinkGreenRedJugglingBalls-JSM-2021-05-31\\config.yaml")
        #sesh.dlcConfigPath = Path("C:\\Users\\jonma\\Desktop\\freemocap\\DLC_Models\\PinkGreenRedJugglingBalls-JSM-2021-05-31\\config.yaml") 
    if stage > 1:
        #if we are rerunning a session folder
        # 1) Check if we're using the last saved dataFolderPath, or if the user wants to choose a different one
        #   a. if the user wants to choose one, bring up a GUI to let them decide
        #   b. if we're using the last known path - parse the user preferences yaml (and check if that yaml exists)
        # 2) Check that the data folder exists
        # 3) If no sessionID was user-input, search the chosen directory for the last session created
        if sesh.setDataPath == True:
            sesh.basePath = runmeGUI.RunChooseDataPathGUI(session)
            sesh.basePath = Path(sesh.basePath)
            #sesh.dataFolderPath = Path(basePath)/sesh.dataFolderName

        elif sesh.userDataPath is not None:
            sesh.basePath = sesh.userDataPath
        else:
            try:
                current_path_to_data = preferences['saved']['path_to_save']
                sesh.basePath = current_path_to_data
            except KeyError:
                print('Saved Data path not found, please choose a new one')
                sesh.basePath = runmeGUI.RunChooseDataPathGUI(session)
                sesh.preferences['saved']['path_to_save'] = str(sesh.basePath)
                sesh.save_user_preferences(sesh.preferences)


        dataFolder = Path(sesh.basePath)/sesh.dataFolderName
        sesh.dataFolderPath = dataFolder
        
        if not dataFolder.exists():
            raise FileNotFoundError('No data folder located at: ' + str(dataFolder))

        if sesh.sessionID == None:    
            subfolders = [f.path for f in os.scandir(sesh.dataFolderPath) if f.is_dir()]  # copy-pasta from who knows where
            sesh.sessionID = Path(subfolders[-1]).stem  # grab the name of the last folder in the list of subfolders
        
        print('Running ' + str(sesh.sessionID) + ' from ' + str(sesh.dataFolderPath))
        
        # if sesh. setDataPath == True:
        #     #run file dialog GUI (select folder where the data folder)
        # here = Path(__file__).parent
        # parameter_path = here/'user_preferences.yaml'
        # if parameter_path.exists(): 
        #     #this section looks for the Data folder at the last saved path from the user_preferences.yaml, if none exists, it raises an error
        #     #if not, if finds the most recent session from that Data folder 
        #     parameters_yaml = YAML()
        #     parameters = parameters_yaml.load(parameter_path)
        #     current_path_to_data = parameters['saved']['path_to_save']
        #     dataFolder = Path(current_path_to_data)/'Data' 
        #     try:
        #         subfolders = [f.path for f in os.scandir(dataFolder) if f.is_dir()]  # copy-pasta from who knows where
        #         sesh.sessionID = Path(subfolders[-1]).stem  # grab the name of the last folder in the list of subfolders
        #     except FileNotFoundError:
        #        raise FileNotFoundError('No data folder located at: ' + str(dataFolder))
            
        #     print('Running ' + str(sesh.sessionID) + ' from ' + str(dataFolder))
        #     sesh.dataPath = dataFolder
    
    
    
    #else: #First time run! Make 'FreeMoCap_Data' Folder (and eventually,  prompt to download sample data)
    #    dataFolder.mkdir()
    #    sampleDataFolder = dataFolder / '_sample_data_folder'
    #    sampleDataFolder.mkdir()

    board = CharucoBoard(7, 5,
                        #square_length=1, # here, in mm but any unit works (JSM NOTE - just using '1' so resulting units will be in 'charuco squarelenghts`)
                        #marker_length=.8,
                        #  square_length = 121, #big boi charuco
                        #  marker_length = 98,
                        square_length = charucoSquareSize,#mm
                        marker_length = charucoSquareSize*.8,#mm
                        marker_bits=4, dict_size=250)


    sesh.board = board
    #sesh.input_stage = stage



    # %% Initialization
    #sesh.initialize(stage)
    if stage ==2 or stage == 1:
        webcamGUI.initialize(sesh,stage,board)
    else:
        sesh.initialize(stage)

    # %% Stage One
    if stage <= 1:
        print()
        print('Starting Video Recordings')
        runcams.RecordCams(sesh, sesh.cam_inputs, sesh.parameterDictionary, sesh.rotationInputs)
        sesh.save_session()
    else:
        print('Skipping Video Recording')


    # %% Stage Two
    if stage <= 2:
        print()
        print('Starting Video Syncing')
        runcams.SyncCams(sesh, sesh.timeStampData,sesh.numCamRange,sesh.vidNames,sesh.camIDs)
        sesh.save_session()
    else:
        print('Skipping Video Syncing')

    # %% Stage Three
    if stage <= 3:
        print()
        print('Starting Calibration')
        sesh.cgroup, sesh.mean_charuco_fr_mar_xyz = calibrate.CalibrateCaptureVolume(sesh,board, calVideoFrameLength)
    else:
        print('Skipping Calibration')

    # %% Stage Four
    if stage <= 4:

        print('Starting Track Image Points')
        if sesh.useMediaPipe:
            if runMediaPipe:
                fmc_mediapipe.runMediaPipe(sesh)

            sesh.mediaPipeData_nCams_nFrames_nImgPts_XYC = fmc_mediapipe.parseMediaPipe(sesh)
            sesh.mediaPipeSkel_fr_mar_xyz, sesh.mediaPipeSkel_reprojErr = reconstruct3D.reconstruct3D(sesh,sesh.mediaPipeData_nCams_nFrames_nImgPts_XYC, confidenceThreshold=reconstructionConfidenceThreshold)
            np.save(sesh.dataArrayPath/'mediaPipeSkel_3d.npy', sesh.mediaPipeSkel_fr_mar_xyz) #save data to npy
            np.save(sesh.dataArrayPath/'mediaPipeSkel_reprojErr.npy', sesh.mediaPipeSkel_reprojErr) #save data to npy            
        sesh.save_session()

        if sesh.useOpenPose:
            fmc_openpose.runOpenPose(sesh, runOpenPose=runOpenPose)
            sesh.openPoseData_nCams_nFrames_nImgPts_XYC = fmc_openpose.parseOpenPose(sesh)
            sesh.openPoseSkel_fr_mar_xyz, sesh.openPoseSkel_reprojErr = reconstruct3D.reconstruct3D(sesh,sesh.openPoseData_nCams_nFrames_nImgPts_XYC, confidenceThreshold=reconstructionConfidenceThreshold)
            np.save(sesh.dataArrayPath/'openPoseSkel_3d.npy', sesh.openPoseSkel_fr_mar_xyz) #save data to npy
            np.save(sesh.dataArrayPath/'openPoseSkel_reprojErr.npy', sesh.openPoseSkel_reprojErr) #save data to npy
        sesh.save_session()
        sesh.syncedVidList = []
        if sesh.useDLC:
            for vid in sesh.syncedVidPath.glob('*.mp4'):
                sesh.syncedVidList.append(str(vid))
            
            for config_path in dlc_config_paths:
                dlc.analyze_videos(config_path,sesh.syncedVidList, destfolder= sesh.dlcDataPath, save_as_csv=True) 
                sesh.dlcData_nCams_nFrames_nImgPts_XYC = fmc_deeplabcut.parseDeepLabCut(sesh, config_path)
                sesh.dlc_fr_mar_xyz, sesh.dlc_reprojErr = reconstruct3D.reconstruct3D(sesh,sesh.dlcData_nCams_nFrames_nImgPts_XYC, confidenceThreshold=reconstructionConfidenceThreshold)
                np.save(sesh.dataArrayPath/'deepLabCut_3d.npy', sesh.dlc_fr_mar_xyz) #save data to npy
                np.save(sesh.dataArrayPath/'deepLabCut_reprojErr.npy', sesh.dlc_reprojErr) #save data to npy
        sesh.save_session()
    else:
        print('Skipping Run MediaPipe')

    # %% Stage Five - Make Skreleton Animation
    if stage <= 5:
        print('Starting Skeleton Plotting')
        play_skeleton_animation.PlaySkeletonAnimation(
                                sesh,
                                startFrame=0,
                                azimuth=-90,
                                elevation=-81,
                                useOpenPose=useOpenPose,
                                useMediaPipe=useMediaPipe,
                                useDLC=useDLC,
                                recordVid = recordVid
                                )
        # print ('Starting PyQT Animation')
        # createvideo.createBodyTrackingVideos(sesh)
        # displayVid = 1  
        # #if displayVid = 0, will show the synced videos
        # #if displayVid = 1, will show the openPosed videos
        # playWin = PlayerDockedWindow(sesh,displayVid)
        # playWin.animate()

    else:
        print('Skipping Skeleton Plotting')



        




from pathlib import Path
from ruamel.yaml import YAML
import datetime
import sys
import pandas as pd
import numpy as np

from freemocap.webcam import recordGUI, camsetup
from freemocap import recordingconfig, fmc_anipose


def initialize(session, stage, board):
    """ 
    Runs the initialization needed to either a) start a new recording from scratch (Stage 1), or b) continue a sesssion from stage 2 (time-syncing).
    
    If running from stage 1: create a new sessionID and attempt to load previous recording parameters (camera settings/rotations/save locations), 
    and use default values if previous parameters are not found. Ask user to select preferences using a series of GUIs, runs the Setup option if 
    chosen by the user, and ultimately sets a bool that dictates whether we should proceed to start the actual Stage 1 recording. Also saves parameters
    into the session class, which gets saved into the user_preferences yaml

    If running from stage 2: loads the timestamps and reads them into a dataframe, and sets up all the parameters necesary to run the pipeline
    """ 

    print("Starting initialization for stage {}".format(stage))
    # if stage == 1:
    filepath = Path.cwd()

    session.board = board

    # %% Stage One Initialization
    if stage == 1:

        # create session ID
        sessionID_in = datetime.datetime.now().strftime("sesh_%Y-%m-%d_%H_%M_%S")
        session.sessionID = sessionID_in

    #load the parameters YAML and extract the saved parameters if possible, and the default otherwise       
        #here = Path(__file__).parent
        # parameter_path = here/'user_preferences.yaml'
        # parameters_yaml = YAML()
        # if parameter_path.exists():
        #     parameters = parameters_yaml.load(parameter_path)
        # else:
        #     parameters = recordingconfig.parameters_for_yaml
        #     with open(parameter_path,'w') as outfile:
        #         parameters_yaml.dump(parameters, outfile)




        proceedToRecording = False #create this boolean, set it to false, and if the user wants to record
                                   #later in the pipeline, it will be set to true

    #run the GUI to get the tasks, the cams chosen, the camera settings, and the session ID
        cam_inputs, task = recordGUI.RunChoiceGUI()
        restartSetup = True

        while restartSetup == True:
            
            try:
                rotation_entry = session.preferences["saved"]["rotations"]
                parameter_entry = session.preferences["saved"]["parameters"]
            except:
                print("Could not load saved parameters, using default parameters")
                rotation_entry = session.preferences['default']['rotations']
                parameter_entry = session.preferences['default']['parameters']
                    

            try:
                current_path_to_save = session.preferences['saved']['path_to_save']
            except:
                current_path_to_save = session.preferences['default']['path_to_save'] 
            rotDict, paramDict, session.sessionID,savepath = recordGUI.RunParametersGUI(sessionID_in, rotation_entry, parameter_entry, current_path_to_save, cam_inputs, task)
        
        #update the saved parameters in the YAML
            #recordingconfig.rotation_settings['saved'] = rotDict
            #recordingconfig.camera_session.preferences['saved'] = paramDict
            session.preferences['saved']['rotations'] = rotDict
            session.preferences['saved']['parameters'] = paramDict
            if savepath is not None:
                session.preferences['saved']['path_to_save'] = savepath

            session.save_user_preferences(session.preferences)

        #save recording parameters to the config yaml

            
        #create a list from the rotation dictionary to be used in running webcams
            rotation_input = list(rotDict.values())

            if task == "setup":
                # run setup processes, and then check if th user wants to proceed to recording
                camsetup.RunSetup(cam_inputs, rotation_input, paramDict)
                proceedToRecording, restartSetup, session.sessionID, savepath = recordGUI.RunProceedtoRecordGUI(
                    sessionID_in,current_path_to_save
                )
                session.preferences['saved']['path_to_save'] = savepath
                session.save_user_preferences(session.preferences)
            elif task == "record":
                proceedToRecording = True
                restartSetup = False

        if proceedToRecording:
            # create these session properties to be used later in the pipeline
            session.cam_inputs = cam_inputs
            session.parameterDictionary = paramDict
            session.rotationInputs = rotation_input
            session.basePath = Path(savepath)

            #create a config yaml and text file for this session
            session.start_session(session.parameterDictionary,session.rotationInputs)
            session.session_settings['recording_parameters']['RotationInputs'] = rotDict
            session.session_settings['recording_parameters']['ParameterDict'] = paramDict
            #configyaml = YAML()
            #sessionsettings = configyaml.load(session.session_yaml_path)
            #sessionsettings['recording_parameters']['RotationInputs'] = rotDict
            #sessionsettings['recording_parameters']['ParameterDict'] = paramDict
            #configyaml.dump(sessionsettings, session.session_yaml_path)
            #print(sessionsettings)
            #config_yaml_path = recordingconfig.createSession(session,filepath)
            #recordingconfig.createSessionTxt(session,paramDict,rotDict)
            
            print('Proceeding to Stage One')        
    
        else:
        
            sys.exit('Recording Canceled')
# %% Stage Two Initalization
    if stage == 2:
        # session.sessionPath = filepath/'Data'/session.sessionID #create a session path based on the sessionID

        # #load the config yaml for this session, and add all the paths to the session file
        # session.yamlPath = session.sessionPath/'{}_config.yaml'.format(session.sessionID)
        # session.config_settings = recordingconfig.load_config_yaml(session.yamlPath) #config settings = paths and camera parameter inputs
        # recordingconfig.load_session_paths(session,session.config_settings) #add paths to session class
        session.initialize(stage)

        #from the config settings add the camera input parameters to parameter dictionary
        session.parameterDictionary = session.session_settings['recording_parameters']['ParameterDict']
        rotationDict = session.session_settings['recording_parameters']['RotationInputs']
        session.rotationInputs = list(rotationDict.values())
        #initialize the path to the timestamp csv
        csvName = session.sessionID + '_timestamps.csv'
        csvPath = session.rawVidPath/csvName

        #read CSV data, turn it into a data frame
        timeStampData = pd.read_csv (csvPath)
        timeStampData = timeStampData.iloc[:,1:]

        #get the camIDs and number of cameras (numCamRange) from the dataframe
        camIDs = list(timeStampData.columns)
        numCams = len(camIDs)
        numCamRange = range(len(camIDs)) 
        
        #create names for each of the raw videos  
        vidNames = []
        for x in numCamRange:
            singleVidName = 'raw_cam{}.mp4'.format(x+1)
            vidNames.append(singleVidName)    


        #initialize all the session variables we'll need to run the rest of the pipeline
        session.timeStampData = timeStampData
        session.camIDs = camIDs
        session.numCamRange = numCamRange
        session.vidNames = vidNames
        session.numCams = numCams

#     if stage == 3:

#         session.sessionPath = (
#             filepath / "Data" / session.sessionID
#         )  # create a session path based on the sessionID

#         # load the config yaml for this session, and add all the paths to the session file
#         session.yamlPath = session.sessionPath / "{}_config.yaml".format(
#             session.sessionID
#         )

#         if (
#             session.yamlPath.is_file()
#         ):  # if the config yaml exists (from a webcam recording)
#             session.config_settings = recordingconfig.load_config_yaml(
#                 session.yamlPath
#             )  # config settings = paths and camera parameter inputs
#             recordingconfig.load_session_paths(
#                 session, session.config_settings
#             )  # add paths to session class
#         else:  # if it doesn't exist (because of a GoPro/external camera recording)
#             recordingconfig.createSession(session, filepath)

#     if stage == 4:

#         session.sessionPath = filepath / "Data" / session.sessionID

#         session.yamlPath = session.sessionPath / "{}_config.yaml".format(
#             session.sessionID
#         )  # path to the configuration yaml
#         session.config_settings = recordingconfig.load_config_yaml(
#             session.yamlPath
#         )  # config settings = paths and camera parameter inputs
#         recordingconfig.load_session_paths(
#             session, session.config_settings
#         )  # add paths to session class

#         for count, thisVidPath in enumerate(
#             session.syncedVidPath.glob("*.mp4"), start=1
#         ):
#             session.numCams = count

#     if stage == 6:

#         session.sessionPath = filepath / "Data" / session.sessionID

#         session.yamlPath = session.sessionPath / "{}_config.yaml".format(
#             session.sessionID
#         )  # path to the configuration yaml
#         session.config_settings = recordingconfig.load_config_yaml(
#             session.yamlPath
#         )  # config settings = paths and camera parameter inputs
#         recordingconfig.load_session_paths(
#             session, session.config_settings
#         )  # add paths to session class

#         if session.useOpenPose:
#             session.openPose_imgPathList = session.config_settings[
#                 "openPose_imgPathList"
#             ]

#         if session.useMediaPipe:
#             session.mediaPipe_imgPathList = session.config_settings[
#                 "mediaPipe_imgPathList"
#             ]

#     # if stage == 5:

#     #     session.sessionPath = filepath/'Data'/session.sessionID

#     #     session.yamlPath = session.sessionPath/'{}_config.yaml'.format(session.sessionID) #path to the configuration yaml
#     #     session.config_settings = recordingconfig.load_config_yaml(session.yamlPath) #config settings = paths and camera parameter inputs
#     #     recordingconfig.load_session_paths(session,session.config_settings) #add paths to session class

#     #     for count,thisVidPath in enumerate(session.syncedVidPath.glob('*.mp4'),start=1):
#     #         session.numCams = count

#     #     session.mediaPipe_jsonPathList = session.config_settings['mediaPipe_jsonPathList']
#     #     session.numCams = len(session.mediaPipe_jsonPathList)

#     # if stage == 6:

#     #     session.sessionPath = filepath/'Data'/session.sessionID

#     #     session.yamlPath = session.sessionPath/'{}_config.yaml'.format(session.sessionID) #path to the configuration yaml
#     #     session.config_settings = recordingconfig.load_config_yaml(session.yamlPath) #config settings = paths and camera parameter inputs
#     #     recordingconfig.load_session_paths(session,session.config_settings) #add paths to session class

#     #     session.mediaPipeData_nCams_nFrames_nImgPts_XY = np.load(session.dataArrayPath/'mediaPipeData_nCams_nFrames_nImgPts_XY.npy')

#     if stage == 7:

#         session.sessionPath = filepath / "Data" / session.sessionID

#         session.yamlPath = session.sessionPath / "{}_config.yaml".format(
#             session.sessionID
#         )  # path to the configuration yaml
#         session.config_settings = recordingconfig.load_config_yaml(
#             session.yamlPath
#         )  # config settings = paths and camera parameter inputs
#         recordingconfig.load_session_paths(
#             session, session.config_settings
#         )  # add paths to session class

#         session.mediaPipe_imgPathList = session.config_settings["mediaPipe_imgPathList"]
#         session.openPose_imgPathList = session.config_settings["openPose_imgPathList"]

#         # session.openPose_imgPathList = session.config_settings['openPose_imgPathList']
#         # session.numCams = len(session.openPose_imgPathList)

#     if stage == 8:

#         session.sessionPath = filepath / "Data" / session.sessionID

#         session.yamlPath = session.sessionPath / "{}_config.yaml".format(
#             session.sessionID
#         )  # path to the configuration yaml
#         session.config_settings = recordingconfig.load_config_yaml(
#             session.yamlPath
#         )  # config settings = paths and camera parameter inputs
#         recordingconfig.load_session_paths(
#             session, session.config_settings
#         )  # add paths to session class


# # %%
